package com.baidu.bdocreader.demo;

import com.baidu.bdocreader.BDocInfo;
import com.baidu.bdocreader.downloader.DocDownloadManager;
import com.baidu.bdocreader.downloader.DocDownloadableItem;
import com.baidu.bdocreader.downloader.DocDownloadableItem.DownloadStatus;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends Activity implements OnClickListener {
    private static final String TAG = "MainActivity";

    BDocInfo docInfo;

    TextView tvUrl;
    TextView tvState;
    Button btnStart;
    Button btnPause;
    Button btnDelete;
    Button btnPlay;
    Button btnPlayOnline;

    SampleObserver observer;

    // Warning: 如果将该对象引用 放在Application子类中，要确认用户名发生改变时，重新调用getInstance，会得到一个新的对象
    DocDownloadManager downloadManager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        String userName = "haoxuesheng";
        downloadManager = DocDownloadManager.getInstance(this, userName);

        /**
         * 特注：因为token有时间限制，以下字段请填写为您自己的信息，否则文档无法显示。
         */
        String host = "BCEDOC"; // 百度云传回的host
        String docId = "doc-gkjraanw4f89uu5"; // 百度云传回的docId
        String docType = "doc"; // 文档类型 doc/ppt/ppts等
        String token = "TOKEN"; // 百度云传回的token
        String thisDocDir = ""; // 文档下载器会返回文档的下载路径，到时通过docInfo.setLocalFileDir更新。
        // !!特注!!：以上目录，指定为空串""时表示在线浏览
        int totalPage = 3; // 总页数，必须准确填写 否则在离线浏览时会有问题
        String docTitle = "百度云文档服务";
        int startPage = 1; // 起始浏览页，最小值为1，请不要填入小于1的值
        
        docInfo = new BDocInfo(host, docId, docType, token)
                .setLocalFileDir(thisDocDir)
                .setTotalPage(totalPage)
                .setDocTitle(docTitle)
                .setStartPage(startPage);
//        docInfo.enablePagePreview(2); // 仅显示前两页
        
        tvUrl = (TextView) this.findViewById(R.id.tvurl);
        tvState = (TextView) this.findViewById(R.id.tvState);
        btnStart = (Button) this.findViewById(R.id.btnStart);
        btnPause = (Button) this.findViewById(R.id.btnPause);
        btnDelete = (Button) this.findViewById(R.id.btnDelete);
        btnPlay = (Button) this.findViewById(R.id.btnPlay);
        btnPlayOnline = (Button) this.findViewById(R.id.btnPlayOnline);
        btnStart.setOnClickListener(this);
        btnPause.setOnClickListener(this);
        btnDelete.setOnClickListener(this);
        btnPlay.setOnClickListener(this);
        btnPlayOnline.setOnClickListener(this);

        observer = new SampleObserver(tvState, docInfo);

        tvUrl.setText("Current docId: " + docInfo.getDocId());
        DocDownloadableItem item = downloadManager.getDocDownloadableItemByDocId(docInfo.getDocId());
        if (item != null) {
            item.addDocObserver(observer);
            observer.update(item);
        } else {
            tvState.setText("state: not started");
        }

    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
        case R.id.btnStart:
            downloadManager.startOrResumeDownloader(docInfo.getDocId(), docInfo.getToken(), docInfo.getHost(),
                    observer);
            break;
        case R.id.btnPause:
            downloadManager.pauseDownloader(docInfo.getDocId());
            break;
        case R.id.btnDelete:
            downloadManager.deleteDownloader(docInfo.getDocId());
            break;
        case R.id.btnPlay:
            DocDownloadableItem downloadItem = downloadManager.getDocDownloadableItemByDocId(docInfo.getDocId());

            if (downloadItem != null && downloadItem.getStatus() == DownloadStatus.COMPLETED) {
                Intent intent = new Intent(this, DocViewActivity.class);
                intent.putExtra("ONE_DOC", docInfo);

                startActivity(intent);
            } else {
                Toast.makeText(this, "Downloading Task is not Completed", Toast.LENGTH_SHORT).show();
            }
            break;
        case R.id.btnPlayOnline:
            Intent intent = new Intent(this, DocViewActivity.class);
            intent.putExtra("ONE_DOC", docInfo);
            startActivity(intent);
            break;
        default:
            break;
        }
    }
}
